@@ -9,6 +9,16 @@ from dovado_rtl.antlr.hdl_representation import PortDirectionEnum
 from dovado_rtl.enums import RegressionModel
 
 
+def validate_nearest_distance(value: int) -> int:
+    if value < 0:
+        raise typer.BadParameter(
+            "Invalid distance value: "
+            + str(value)
+            + " non-negative integer expected"
+        )
+    return value
+
+
 def validate_estimator(value: str) -> str:
     if value.upper() not in RegressionModel.__members__.keys():
         raise typer.BadParameter(
