@@ -2,7 +2,6 @@ from pathlib import Path
 from typing import Tuple, List, Optional
 from collections import OrderedDict
 
-from numpy.core.defchararray import upper
 from dovado_rtl.config import Configuration
 import dovado_rtl.vivado_interaction as vivado
 from dovado_rtl.frame_handling import (
@@ -23,6 +22,7 @@ from dovado_rtl.cli_utility import (
     validate_directives,
     validate_target_clock,
     validate_estimator,
+    validate_nearest_distance,
 )
 import typer
 
@@ -221,12 +221,20 @@ def space(
         help="list of integers in which each odd indexed element starts"
         + " a range and the consecutive closes it (start counting from 1)",
     ),
+    approximate: bool = typer.Option(
+        False, help="enable approximations for fitness function"
+    ),
     fitness_estimator: str = typer.Option(
         "KERNEL_RIDGE",
         callback=validate_estimator,
         help="estimator to use for fitness function approximation,"
         + "'kernel_ridge' is default. 'stream_learning' selects a Hoeffding Adaptive Tree Regressor trained incrementally",
     ),
+    nearest_distance: int = typer.Option(
+        3,
+        callback=validate_nearest_distance,
+        help="Set which nearest distance is considered against the threshold",
+    ),
     test_estimation: bool = typer.Option(
         False,
         help="record all estimated values along with the real "
@@ -263,7 +271,11 @@ def space(
     )
 
     fitness_evaluator = FitnessEvaluator(
-        estimator, ctx.obj["point_evaluator"], ctx.obj["config"]
+        approximate,
+        nearest_distance,
+        estimator,
+        ctx.obj["point_evaluator"],
+        ctx.obj["config"],
     )
 
     # TODO ask user for initial parameters so as to be sure to have a correct first synthesis/implementation
